@@ -25,12 +25,12 @@
 class SystemException : public std::exception
 {
 public:
-    SystemException() { m_msg = "system error"; }
+    SystemException() { m_msg = QStringLiteral("system error"); }
     SystemException(const QString &msg) { m_msg = msg; }
 
     ~SystemException() throw() { }
 
-    virtual const char *what() const throw() {
+    const char *what() const throw() Q_DECL_OVERRIDE {
         return m_msg.toLatin1();
     }
 
